@@ -59,34 +59,16 @@ else
 	# These dummy functions are for things that are likely to be called
 	# in global scope, even though they are completely useless during
 	# the "depend" phase.
-	for x in diropts docompress exeopts get_KV insopts \
-		KV_major KV_micro KV_minor KV_to_int \
-		libopts register_die_hook register_success_hook \
-		__strip_duplicate_slashes \
-		use_with use_enable ; do
-		eval "${x}() {
-			if ___eapi_disallows_helpers_in_global_scope; then
-				die \"\${FUNCNAME}() calls are not allowed in global scope\"
-			fi
-		}"
-	done
-	# These dummy functions return false in non-strict EAPIs, in order to ensure that
-	# `use multislot` is false for the "depend" phase.
-	funcs="use useq usev"
+	funcs="diropts docompress exeopts get_KV insopts
+		KV_major KV_micro KV_minor KV_to_int
+		libopts register_die_hook register_success_hook
+		__strip_duplicate_slashes
+		use useq usev use_with use_enable"
 	___eapi_has_usex && funcs+=" usex"
 	___eapi_has_in_iuse && funcs+=" in_iuse"
-	for x in ${funcs} ; do
-		eval "${x}() {
-			if ___eapi_disallows_helpers_in_global_scope; then
-				die \"\${FUNCNAME}() calls are not allowed in global scope\"
-			else
-				return 1
-			fi
-		}"
-	done
 	# These functions die because calls to them during the "depend" phase
 	# are considered to be severe QA violations.
-	funcs="best_version has_version portageq"
+	funcs+=" best_version has_version portageq"
 	___eapi_has_master_repositories && funcs+=" master_repositories"
 	___eapi_has_repository_path && funcs+=" repository_path"
 	___eapi_has_available_eclasses && funcs+=" available_eclasses"
@@ -185,9 +167,14 @@ export SANDBOX_ON=0
 
 # Ensure that $PWD is sane whenever possible, to protect against
 # exploitation of insecure search path for python -c in ebuilds.
-# See bug #239560 and bug #469338.
-cd "${PORTAGE_PYM_PATH}" || \
-	die "PORTAGE_PYM_PATH does not exist: '${PORTAGE_PYM_PATH}'"
+# See bug #239560, bug #469338, and bug #595028.
+if [[ -d ${HOME} ]]; then
+	# Use portage's temporary HOME directory if available.
+	cd "${HOME}" || die
+else
+	cd "${PORTAGE_PYM_PATH}" || \
+		die "PORTAGE_PYM_PATH does not exist: '${PORTAGE_PYM_PATH}'"
+fi
 
 #if no perms are specified, dirs/files will have decent defaults
 #(not secretive, but not stupid)
@@ -704,31 +691,6 @@ if ! has "$EBUILD_PHASE" clean cleanrm ; then
 
 				[[ -n $CCACHE_SIZE ]] && ccache -M $CCACHE_SIZE &> /dev/null
 			fi
-
-			if [[ -n $QA_PREBUILT ]] ; then
-
-				# these ones support fnmatch patterns
-				QA_EXECSTACK+=" $QA_PREBUILT"
-				QA_TEXTRELS+=" $QA_PREBUILT"
-				QA_WX_LOAD+=" $QA_PREBUILT"
-
-				# these ones support regular expressions, so translate
-				# fnmatch patterns to regular expressions
-				for x in QA_DT_NEEDED QA_FLAGS_IGNORED QA_PRESTRIPPED QA_SONAME ; do
-					if [[ $(declare -p $x 2>/dev/null) = declare\ -a* ]] ; then
-						eval "$x=(\"\${$x[@]}\" ${QA_PREBUILT//\*/.*})"
-					else
-						eval "$x+=\" ${QA_PREBUILT//\*/.*}\""
-					fi
-				done
-
-				unset x
-			fi
-
-			# This needs to be exported since prepstrip is a separate shell script.
-			[[ -n $QA_PRESTRIPPED ]] && export QA_PRESTRIPPED
-			eval "[[ -n \$QA_PRESTRIPPED_${ARCH/-/_} ]] && \
-				export QA_PRESTRIPPED_${ARCH/-/_}"
 		fi
 	fi
 fi
